@@ -3,9 +3,11 @@
 
 #include <QProcess>
 #include <QtCore/QCoreApplication>
+#include <QDesktopServices>
+#include <QUrl>
 
 MainWindow::MainWindow(QWidget *parent)
-    : QMainWindow(parent), ui(new Ui::MainWindow)
+    : QMainWindow(parent), ui(new Ui::MainWindow), m_process(new QProcess(this))
 {
     ui->setupUi(this);
 }
@@ -71,15 +73,10 @@ void MainWindow::showExpanded()
 
 void MainWindow::on_pushButtonStart_clicked()
 {
-    QProcess *process;
-            process = new QProcess( this );
-            process->start("sh opt/tenminutecore/script/tenminutecore.sh");
+    m_process->start("sh opt/tenminutecore/script/tenminutecore.sh");
 }
 
-void MainWindow::on_pushButtonStop_clicked()
+void MainWindow::on_pushButtonHelp_clicked()
 {
-    QProcess *process;
-            process = new QProcess( this );
-            process->start("sh opt/tenminutecore/script/kill.sh");
-            process->waitForFinished();
+    QDesktopServices::openUrl(QUrl("http://wiki.maemo.org/Tenminutecore#The_Exercises"));
 }
