@@ -2,6 +2,7 @@
 #define MAINWINDOW_H
 
 #include <QtGui/QMainWindow>
+#include <QProcess>
 
 namespace Ui {
     class MainWindow;
@@ -28,10 +29,11 @@ public:
 private slots:
     void on_pushButtonStart_clicked();
 
-    void on_pushButtonStop_clicked();
+    void on_pushButtonHelp_clicked();
 
 private:
     Ui::MainWindow *ui;
+    QProcess *m_process;
 };
 
 #endif // MAINWINDOW_H
